@@ -15,6 +15,10 @@ def grid_cache_dir(grid_dir):
     return os.path.join(grid_dir, base.GRID_CACHE)
 
 
+def grid_stream_dir(grid_dir):
+    return os.path.join(grid_dir, base.GRID_STREAM)
+
+
 def grid_cache_tile_dir(grid_dir, tile_name):
     return os.path.join(grid_cache_dir(grid_dir), tile_name)
 
@@ -23,6 +27,7 @@ def clear_grid(grid_dir):
     shutil.rmtree(grid_dir)
     os.mkdir(grid_dir)
     os.mkdir(grid_tiles_dir(grid_dir))
+    os.mkdir(grid_stream_dir(grid_dir))
     os.mkdir(grid_cache_dir(grid_dir))
 
 
@@ -36,6 +41,11 @@ def grid_tile(grid_dir, tile_name):
     return os.path.join(tiles_dir, f"{tile_name}.json")
 
 
+def grid_stream(grid_dir, tile_name):
+    tiles_dir = grid_stream_dir(grid_dir)
+    return os.path.join(tiles_dir, f"{tile_name}.json")
+
+
 def tile_name(x: int, y: int):
     return f'tile{x}_{y}'
 
@@ -47,6 +57,7 @@ def tile_xy(name: str):
 def grid_dir(layer_dir):
     return os.path.join(layer_dir, base.GRID)
 
+
 def grid_tiles(grid_dir):
     tile_dir = grid_tiles_dir(grid_dir)
     for tile in os.listdir(tile_dir):
